#!/usr/bin/perl -w
#
# Test for namazu.  Searching an index created with --html-split option.
#

use strict;
require Cwd;
require 'pltests.pl';

my $cwd = Cwd::getcwd();
my $LOG = "$cwd/test-log";
my $INDEX = "$cwd/idx9";
my $NAMAZU = pltests::binpath('namazu');

my $cmd;

pltests::putline($LOG, "  *** starting $0");

my $docnum;
my $doc = pltests::cat("$INDEX/NMZ.status");
unless (defined $doc) {
    exit 1;
}
if ($doc =~ /^files (\d+)/m) {
    $docnum = $1;
} else {
    exit 1;
}

# All parts should have "test".
$cmd = "$NAMAZU -c test $INDEX";
my $hitnum = `$cmd`;
unless (defined $hitnum) {
    exit 1;
}

pltests::putline($LOG, "docnum: $docnum hitnum: $hitnum");

if ($docnum != $hitnum) {
    exit 1;
}

# For 1.html. Each keyword should match only one part.
$cmd = "$NAMAZU -c xyzzy $INDEX";
$hitnum = `$cmd`;
chomp $hitnum;
unless (defined $hitnum) {
    exit 1;
}

pltests::putline($LOG, "xyzzy $hitnum");

if ($hitnum != 1) {
    exit 1;
}


$cmd = "$NAMAZU -c \"foo foo1\" $INDEX";
$hitnum = `$cmd`;
chomp $hitnum;
unless (defined $hitnum) {
    exit 1;
}

pltests::putline($LOG, "\"foo foo1\" $hitnum");

if ($hitnum != 1) {
    exit 1;
}


$cmd = "$NAMAZU -c \"bar bar2\" $INDEX";
$hitnum = `$cmd`;
chomp $hitnum;
unless (defined $hitnum) {
    exit 1;
}

pltests::putline($LOG, "\"bar bar2\" $hitnum");

if ($hitnum != 1) {
    exit 1;
}


$cmd = "$NAMAZU -c \"baz baz3\" $INDEX";
$hitnum = `$cmd`;
chomp $hitnum;
unless (defined $hitnum) {
    exit 1;
}

pltests::putline($LOG, "\"baz baz3\" $hitnum");

if ($hitnum != 1) {
    exit 1;
}


$cmd = "$NAMAZU -c \"qux qux4\" $INDEX";
$hitnum = `$cmd`;
chomp $hitnum;
unless (defined $hitnum) {
    exit 1;
}

pltests::putline($LOG, "\"qux qux4\" $hitnum");

if ($hitnum != 1) {
    exit 1;
}


$cmd = "$NAMAZU -c \"quux quux5\" $INDEX";
$hitnum = `$cmd`;
chomp $hitnum;
unless (defined $hitnum) {
    exit 1;
}

pltests::putline($LOG, "\"quux quux5\" $hitnum");

if ($hitnum != 1) {
    exit 1;
}

# For 2.html. Each keyword should match only one part.
$cmd = "$NAMAZU -c orabidoo $INDEX";
$hitnum = `$cmd`;
chomp $hitnum;
unless (defined $hitnum) {
    exit 1;
}

pltests::putline($LOG, "orabidoo $hitnum");

if ($hitnum != 1) {
    exit 1;
}


$cmd = "$NAMAZU -c \"zero foo\" $INDEX";
$hitnum = `$cmd`;
chomp $hitnum;
unless (defined $hitnum) {
    exit 1;
}

pltests::putline($LOG, "\"zero foo\" $hitnum");

if ($hitnum != 1) {
    exit 1;
}


$cmd = "$NAMAZU -c \"bar one\" $INDEX";
$hitnum = `$cmd`;
chomp $hitnum;
unless (defined $hitnum) {
    exit 1;
}

pltests::putline($LOG, "\"bar one\" $hitnum");

if ($hitnum != 1) {
    exit 1;
}


$cmd = "$NAMAZU -c \"baz two\" $INDEX";
$hitnum = `$cmd`;
chomp $hitnum;
unless (defined $hitnum) {
    exit 1;
}

pltests::putline($LOG, "\"baz two\" $hitnum");

if ($hitnum != 1) {
    exit 1;
}


$cmd = "$NAMAZU -c \"qux three\" $INDEX";
$hitnum = `$cmd`;
chomp $hitnum;
unless (defined $hitnum) {
    exit 1;
}

pltests::putline($LOG, "\"qux three\" $hitnum");

if ($hitnum != 1) {
    exit 1;
}


$cmd = "$NAMAZU -c \"quux four\" $INDEX";
$hitnum = `$cmd`;
chomp $hitnum;
unless (defined $hitnum) {
    exit 1;
}

pltests::putline($LOG, "\"quux four\" $hitnum");

if ($hitnum != 1) {
    exit 1;
}

exit 0;
